@@ -5,7 +5,7 @@
 #' impact of a variable on a self-defined measure, like the Gini Index.
 #' @keywords internal
 
-ex_f <- function(pred_params, ex_fun) {
+ex_f <- function(pred_params, ex_fun, samples) {
 
   # Obtain the function from the string
   fun <- get(ex_fun, envir = .GlobalEnv)
@@ -15,8 +15,17 @@ ex_f <- function(pred_params, ex_fun) {
     stop("Argument 'ex-fun' has to be a function!")
 
   # Get values
-  vals <- apply(pred_params, 1, FUN = fun)
+  if (!samples)
+    vals <- fun(pred_params)
+  if (samples)
+    vals <- lapply(pred_params, FUN = function(listparts) {
+      apply(listparts, 1, FUN = function(x) {
+        x <- as.list(x)
+        return(fun(x))
+      })
+    })
 
   # Return values
   return(vals)
 }
+
